::: sleeplab_format.writer
    options:
        members:
            - write_dataset
            - write_series
            - write_subject
            - write_annotations
            - write_sample_arrays
            - write_subject_metadata
